@@ -31,8 +31,8 @@ typedef enum LocaleVariable {
 
 #if 0 /// UNNEEDED by elogind
 int get_locales(char ***l);
-#endif // 0
 bool locale_is_valid(const char *name);
+#endif // 0
 
 #define _(String) gettext(String)
 #define N_(String) String
@@ -50,14 +50,12 @@ typedef enum {
         SPECIAL_GLYPH_TRIANGULAR_BULLET,
         SPECIAL_GLYPH_BLACK_CIRCLE,
         SPECIAL_GLYPH_BULLET,
+        SPECIAL_GLYPH_ARROW,
+        SPECIAL_GLYPH_MDASH,
+        SPECIAL_GLYPH_ELLIPSIS,
         SPECIAL_GLYPH_MU,
         SPECIAL_GLYPH_CHECK_MARK,
         SPECIAL_GLYPH_CROSS_MARK,
-        SPECIAL_GLYPH_ARROW,
-        SPECIAL_GLYPH_ELLIPSIS,
-        SPECIAL_GLYPH_LIGHT_SHADE,
-        SPECIAL_GLYPH_DARK_SHADE,
-        SPECIAL_GLYPH_SIGMA,
         _SPECIAL_GLYPH_FIRST_SMILEY,
         SPECIAL_GLYPH_ECSTATIC_SMILEY = _SPECIAL_GLYPH_FIRST_SMILEY,
         SPECIAL_GLYPH_HAPPY_SMILEY,
