@@ -6,10 +6,14 @@
 #include <limits.h>
 #include <stdarg.h>
 #include <stddef.h>
+#include <stdio.h>
+#include <string.h>
 #include <sys/signalfd.h>
+#include <sys/socket.h>
 #include <sys/time.h>
-#include <sys/uio.h>
-#include <sys/un.h>
+//#include <sys/uio.h>
+//#include <sys/un.h>
+#include <time.h>
 #include <unistd.h>
 
 #include "sd-messages.h"
@@ -21,10 +25,10 @@
 #include "io-util.h"
 #include "log.h"
 #include "macro.h"
+#include "missing.h"
 #include "parse-util.h"
 #include "proc-cmdline.h"
 #include "process-util.h"
-#include "ratelimit.h"
 #include "signal-util.h"
 #include "socket-util.h"
 #include "stdio-util.h"
@@ -262,8 +266,14 @@ int log_open(void) {
 #endif // 0
 
                 if (!prohibit_ipc &&
+#if 0 /// Add syslog to elogind LOG_TARGET_AUTO set
                     IN_SET(log_target, LOG_TARGET_SYSLOG_OR_KMSG,
                                        LOG_TARGET_SYSLOG)) {
+#else // 0
+                    IN_SET(log_target, LOG_TARGET_AUTO,
+                                       LOG_TARGET_SYSLOG_OR_KMSG,
+                                       LOG_TARGET_SYSLOG)) {
+#endif // 0
                         r = log_open_syslog();
                         if (r >= 0) {
                                 log_close_journal();
@@ -467,15 +477,6 @@ static int write_to_kmsg(
                 const char *func,
                 const char *buffer) {
 
-        /* Set a ratelimit on the amount of messages logged to /dev/kmsg. This is mostly supposed to be a
-         * safety catch for the case where start indiscriminately logging in a loop. It will not catch cases
-         * where we log excessively, but not in a tight loop.
-         *
-         * Note that this ratelimit is per-emitter, so we might still overwhelm /dev/kmsg with multiple
-         * loggers.
-         */
-        static thread_local RateLimit ratelimit = { 5 * USEC_PER_SEC, 200 };
-
         char header_priority[2 + DECIMAL_STR_MAX(int) + 1],
              header_pid[4 + DECIMAL_STR_MAX(pid_t) + 1];
         struct iovec iovec[5] = {};
@@ -483,9 +484,6 @@ static int write_to_kmsg(
         if (kmsg_fd < 0)
                 return 0;
 
-        if (!ratelimit_below(&ratelimit))
-                return 0;
-
         xsprintf(header_priority, "<%i>", level);
         xsprintf(header_pid, "["PID_FMT"]: ", getpid_cached());
 
