@@ -5,6 +5,7 @@
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include "alloc-util.h"
 #include "escape.h"
@@ -16,8 +17,8 @@
 #include "string-util.h"
 #include "strv.h"
 
-char *strv_find(char * const *l, const char *name) {
-        char * const *i;
+char *strv_find(char **l, const char *name) {
+        char **i;
 
         assert(name);
 
@@ -28,8 +29,8 @@ char *strv_find(char * const *l, const char *name) {
         return NULL;
 }
 
-char *strv_find_prefix(char * const *l, const char *name) {
-        char * const *i;
+char *strv_find_prefix(char **l, const char *name) {
+        char **i;
 
         assert(name);
 
@@ -40,8 +41,8 @@ char *strv_find_prefix(char * const *l, const char *name) {
         return NULL;
 }
 
-char *strv_find_startswith(char * const *l, const char *name) {
-        char * const *i, *e;
+char *strv_find_startswith(char **l, const char *name) {
+        char **i, *e;
 
         assert(name);
 
@@ -57,15 +58,20 @@ char *strv_find_startswith(char * const *l, const char *name) {
         return NULL;
 }
 
-char **strv_free(char **l) {
+void strv_clear(char **l) {
         char **k;
 
         if (!l)
-                return NULL;
+                return;
 
         for (k = l; *k; k++)
                 free(*k);
 
+        *l = NULL;
+}
+
+char **strv_free(char **l) {
+        strv_clear(l);
         return mfree(l);
 }
 
@@ -176,8 +182,9 @@ char **strv_new_internal(const char *x, ...) {
         return r;
 }
 
-int strv_extend_strv(char ***a, char * const *b, bool filter_duplicates) {
-        char * const *s, **t;
+#if 0 /// UNNEEDED by elogind
+int strv_extend_strv(char ***a, char **b, bool filter_duplicates) {
+        char **s, **t;
         size_t p, q, i = 0, j;
 
         assert(a);
@@ -188,10 +195,7 @@ int strv_extend_strv(char ***a, char * const *b, bool filter_duplicates) {
         p = strv_length(*a);
         q = strv_length(b);
 
-        if (p >= SIZE_MAX - q)
-                return -ENOMEM;
-
-        t = reallocarray(*a, GREEDY_ALLOC_ROUND_UP(p + q + 1), sizeof(char *));
+        t = reallocarray(*a, p + q + 1, sizeof(char *));
         if (!t)
                 return -ENOMEM;
 
@@ -223,10 +227,9 @@ rollback:
         return -ENOMEM;
 }
 
-#if 0 /// UNNEEDED by elogind
-int strv_extend_strv_concat(char ***a, char * const *b, const char *suffix) {
-        char * const *s;
+int strv_extend_strv_concat(char ***a, char **b, const char *suffix) {
         int r;
+        char **s;
 
         STRV_FOREACH(s, b) {
                 char *v;
@@ -345,9 +348,9 @@ int strv_split_extract(char ***t, const char *s, const char *separators, Extract
         return (int) n;
 }
 
-char *strv_join_prefix(char * const *l, const char *separator, const char *prefix) {
-        char * const *s;
+char *strv_join_prefix(char **l, const char *separator, const char *prefix) {
         char *r, *e;
+        char **s;
         size_t n, k, m;
 
         if (!separator)
@@ -387,18 +390,19 @@ char *strv_join_prefix(char * const *l, const char *separator, const char *prefi
 #endif // 0
 int strv_push(char ***l, char *value) {
         char **c;
-        size_t n;
+        size_t n, m;
 
         if (!value)
                 return 0;
 
         n = strv_length(*l);
 
-        /* Check for overflow */
-        if (n > SIZE_MAX-2)
+        /* Increase and check for overflow */
+        m = n + 2;
+        if (m < n)
                 return -ENOMEM;
 
-        c = reallocarray(*l, GREEDY_ALLOC_ROUND_UP(n + 2), sizeof(char*));
+        c = reallocarray(*l, m, sizeof(char*));
         if (!c)
                 return -ENOMEM;
 
@@ -411,19 +415,19 @@ int strv_push(char ***l, char *value) {
 
 int strv_push_pair(char ***l, char *a, char *b) {
         char **c;
-        size_t n;
+        size_t n, m;
 
         if (!a && !b)
                 return 0;
 
         n = strv_length(*l);
 
-        /* Check for overflow */
-        if (n > SIZE_MAX-3)
+        /* increase and check for overflow */
+        m = n + !!a + !!b + 1;
+        if (m < n)
                 return -ENOMEM;
 
-        /* increase and check for overflow */
-        c = reallocarray(*l, GREEDY_ALLOC_ROUND_UP(n + !!a + !!b + 1), sizeof(char*));
+        c = reallocarray(*l, m, sizeof(char*));
         if (!c)
                 return -ENOMEM;
 
@@ -492,6 +496,7 @@ int strv_consume_pair(char ***l, char *a, char *b) {
 
         return r;
 }
+#endif // 0
 
 int strv_consume_prepend(char ***l, char *value) {
         int r;
@@ -502,7 +507,6 @@ int strv_consume_prepend(char ***l, char *value) {
 
         return r;
 }
-#endif // 0
 
 int strv_extend(char ***l, const char *value) {
         char *v;
@@ -517,7 +521,6 @@ int strv_extend(char ***l, const char *value) {
         return strv_consume(l, v);
 }
 
-#if 0 /// UNNEEDED by elogind
 int strv_extend_front(char ***l, const char *value) {
         size_t n, m;
         char *v, **c;
@@ -553,7 +556,6 @@ int strv_extend_front(char ***l, const char *value) {
         *l = c;
         return 0;
 }
-#endif // 0
 
 char **strv_uniq(char **l) {
         char **i;
@@ -568,8 +570,8 @@ char **strv_uniq(char **l) {
 }
 
 #if 0 /// UNNEEDED by elogind
-bool strv_is_uniq(char * const *l) {
-        char * const *i;
+bool strv_is_uniq(char **l) {
+        char **i;
 
         STRV_FOREACH(i, l)
                 if (strv_find(i+1, *i))
@@ -674,7 +676,7 @@ char **strv_split_nulstr(const char *s) {
 }
 
 #if 0 /// UNNEEDED by elogind
-int strv_make_nulstr(char * const *l, char **ret, size_t *ret_size) {
+int strv_make_nulstr(char **l, char **p, size_t *q) {
         /* A valid nulstr with two NULs at the end will be created, but
          * q will be the length without the two trailing NULs. Thus the output
          * string is a valid nulstr and can be iterated over using NULSTR_FOREACH,
@@ -684,10 +686,10 @@ int strv_make_nulstr(char * const *l, char **ret, size_t *ret_size) {
 
         size_t n_allocated = 0, n = 0;
         _cleanup_free_ char *m = NULL;
-        char * const *i;
+        char **i;
 
-        assert(ret);
-        assert(ret_size);
+        assert(p);
+        assert(q);
 
         STRV_FOREACH(i, l) {
                 size_t z;
@@ -711,16 +713,16 @@ int strv_make_nulstr(char * const *l, char **ret, size_t *ret_size) {
                 m[n] = '\0';
 
         assert(n > 0);
-        *ret = m;
-        *ret_size = n - 1;
+        *p = m;
+        *q = n - 1;
 
         m = NULL;
 
         return 0;
 }
 
-bool strv_overlap(char * const *a, char * const *b) {
-        char * const *i;
+bool strv_overlap(char **a, char **b) {
+        char **i;
 
         STRV_FOREACH(i, a)
                 if (strv_contains(b, *i))
@@ -739,30 +741,23 @@ char **strv_sort(char **l) {
         return l;
 }
 
-int strv_compare(char * const *a, char * const *b) {
-        int r;
+bool strv_equal(char **a, char **b) {
 
-        if (strv_isempty(a)) {
-                if (strv_isempty(b))
-                        return 0;
-                else
-                        return -1;
-        }
+        if (strv_isempty(a))
+                return strv_isempty(b);
 
         if (strv_isempty(b))
-                return 1;
+                return false;
 
-        for ( ; *a || *b; ++a, ++b) {
-                r = strcmp_ptr(*a, *b);
-                if (r != 0)
-                        return r;
-        }
+        for ( ; *a || *b; ++a, ++b)
+                if (!streq_ptr(*a, *b))
+                        return false;
 
-        return 0;
+        return true;
 }
 
-void strv_print(char * const *l) {
-        char * const *s;
+void strv_print(char **l) {
+        char **s;
 
         STRV_FOREACH(s, l)
                 puts(*s);
@@ -817,13 +812,12 @@ char **strv_shell_escape(char **l, const char *bad) {
         return l;
 }
 
-bool strv_fnmatch_full(char* const* patterns, const char *s, int flags, size_t *matched_pos) {
-        for (size_t i = 0; patterns && patterns[i]; i++)
-                if (fnmatch(patterns[i], s, flags) == 0) {
-                        if (matched_pos)
-                                *matched_pos = i;
+bool strv_fnmatch(char* const* patterns, const char *s, int flags) {
+        char* const* p;
+
+        STRV_FOREACH(p, patterns)
+                if (fnmatch(*p, s, flags) == 0)
                         return true;
-                }
 
         return false;
 }
@@ -867,10 +861,8 @@ int strv_extend_n(char ***l, const char *value, size_t n) {
         /* Adds the value n times to l */
 
         k = strv_length(*l);
-        if (n >= SIZE_MAX - k)
-                return -ENOMEM;
 
-        nl = reallocarray(*l, GREEDY_ALLOC_ROUND_UP(k + n + 1), sizeof(char *));
+        nl = reallocarray(*l, k + n + 1, sizeof(char *));
         if (!nl)
                 return -ENOMEM;
 
@@ -894,9 +886,9 @@ rollback:
 }
 
 #if 0 /// UNNEEDED by elogind
-int fputstrv(FILE *f, char * const *l, const char *separator, bool *space) {
+int fputstrv(FILE *f, char **l, const char *separator, bool *space) {
         bool b = false;
-        char * const *s;
+        char **s;
         int r;
 
         /* Like fputs(), but for strv, and with a less stupid argument order */
