@@ -1,6 +1,7 @@
 /* SPDX-License-Identifier: LGPL-2.1+ */
 
 #include <fcntl.h>
+#include <pwd.h>
 #include <sys/ioctl.h>
 #include <sys/types.h>
 #include <linux/vt.h>
@@ -27,7 +28,6 @@
 #include "terminal-util.h"
 #include "udev-util.h"
 #include "user-util.h"
-#include "userdb.h"
 /// Additional includes needed by elogind
 #include "elogind.h"
 
@@ -63,6 +63,7 @@ void manager_reset_config(Manager *m) {
         m->idle_action = HANDLE_IGNORE;
 
         m->runtime_dir_size = physical_memory_scale(10U, 100U); /* 10% */
+        m->user_tasks_max = system_tasks_max_scale(DEFAULT_USER_TASKS_MAX_PERCENTAGE, 100U); /* 33% */
         m->sessions_max = 8192;
         m->inhibitors_max = 8192;
 
@@ -144,7 +145,7 @@ int manager_parse_config_file(Manager *m) {
                                         CONFIG_PARSE_WARN, m);
 }
 
-int manager_add_device(Manager *m, const char *sysfs, bool master, Device **ret_device) {
+int manager_add_device(Manager *m, const char *sysfs, bool master, Device **_device) {
         Device *d;
 
         assert(m);
@@ -160,13 +161,13 @@ int manager_add_device(Manager *m, const char *sysfs, bool master, Device **ret_
                         return -ENOMEM;
         }
 
-        if (ret_device)
-                *ret_device = d;
+        if (_device)
+                *_device = d;
 
         return 0;
 }
 
-int manager_add_seat(Manager *m, const char *id, Seat **ret_seat) {
+int manager_add_seat(Manager *m, const char *id, Seat **_seat) {
         Seat *s;
         int r;
 
@@ -180,13 +181,13 @@ int manager_add_seat(Manager *m, const char *id, Seat **ret_seat) {
                         return r;
         }
 
-        if (ret_seat)
-                *ret_seat = s;
+        if (_seat)
+                *_seat = s;
 
         return 0;
 }
 
-int manager_add_session(Manager *m, const char *id, Session **ret_session) {
+int manager_add_session(Manager *m, const char *id, Session **_session) {
         Session *s;
         int r;
 
@@ -200,32 +201,35 @@ int manager_add_session(Manager *m, const char *id, Session **ret_session) {
                         return r;
         }
 
-        if (ret_session)
-                *ret_session = s;
+        if (_session)
+                *_session = s;
 
         return 0;
 }
 
 int manager_add_user(
                 Manager *m,
-                UserRecord *ur,
-                User **ret_user) {
+                uid_t uid,
+                gid_t gid,
+                const char *name,
+                const char *home,
+                User **_user) {
 
         User *u;
         int r;
 
         assert(m);
-        assert(ur);
+        assert(name);
 
-        u = hashmap_get(m->users, UID_TO_PTR(ur->uid));
+        u = hashmap_get(m->users, UID_TO_PTR(uid));
         if (!u) {
-                r = user_new(&u, m, ur);
+                r = user_new(&u, m, uid, gid, name, home);
                 if (r < 0)
                         return r;
         }
 
-        if (ret_user)
-                *ret_user = u;
+        if (_user)
+                *_user = u;
 
         return 0;
 }
@@ -233,37 +237,34 @@ int manager_add_user(
 int manager_add_user_by_name(
                 Manager *m,
                 const char *name,
-                User **ret_user) {
+                User **_user) {
 
-        _cleanup_(user_record_unrefp) UserRecord *ur = NULL;
+        const char *home = NULL;
+        uid_t uid;
+        gid_t gid;
         int r;
 
         assert(m);
         assert(name);
 
-        r = userdb_by_name(name, 0, &ur);
+        r = get_user_creds(&name, &uid, &gid, &home, NULL, 0);
         if (r < 0)
                 return r;
 
-        return manager_add_user(m, ur, ret_user);
+        return manager_add_user(m, uid, gid, name, home, _user);
 }
 
-int manager_add_user_by_uid(
-                Manager *m,
-                uid_t uid,
-                User **ret_user) {
-
-        _cleanup_(user_record_unrefp) UserRecord *ur = NULL;
-        int r;
+int manager_add_user_by_uid(Manager *m, uid_t uid, User **_user) {
+        struct passwd *p;
 
         assert(m);
-        assert(uid_is_valid(uid));
 
-        r = userdb_by_uid(uid, 0, &ur);
-        if (r < 0)
-                return r;
+        errno = 0;
+        p = getpwuid(uid);
+        if (!p)
+                return errno_or_else(ENOENT);
 
-        return manager_add_user(m, ur, ret_user);
+        return manager_add_user(m, uid, p->pw_gid, p->pw_name, p->pw_dir, _user);
 }
 
 int manager_add_inhibitor(Manager *m, const char* id, Inhibitor **ret) {
@@ -286,7 +287,7 @@ int manager_add_inhibitor(Manager *m, const char* id, Inhibitor **ret) {
         return 0;
 }
 
-int manager_add_button(Manager *m, const char *name, Button **ret_button) {
+int manager_add_button(Manager *m, const char *name, Button **_button) {
         Button *b;
 
         assert(m);
@@ -299,8 +300,8 @@ int manager_add_button(Manager *m, const char *name, Button **ret_button) {
                         return -ENOMEM;
         }
 
-        if (ret_button)
-                *ret_button = b;
+        if (_button)
+                *_button = b;
 
         return 0;
 }
@@ -428,33 +429,44 @@ int manager_get_session_by_pid(Manager *m, pid_t pid, Session **ret) {
         if (!s) {
 #if 0 /// elogind does not support systemd units, but its own session system
                 r = cg_pid_get_unit(pid, &unit);
-                if (r >= 0)
-                        s = hashmap_get(m->session_units, unit);
+                if (r < 0)
+                        goto not_found;
+
+                s = hashmap_get(m->session_units, unit);
+                if (!s)
+                        goto not_found;
 #else // 0
                 log_debug_elogind("Searching session for PID %u", pid);
                 r = cg_pid_get_session(pid, &session_name);
+                if (r < 0)
+                        goto not_found;
 
-                if (r >= 0)
-                        s = hashmap_get(m->sessions, session_name);
-
+                s = hashmap_get(m->sessions, session_name);
+                if (!s)
+                        goto not_found;
                 log_debug_elogind("Session Name \"%s\" -> Session \"%s\"",
-                                  strnull(session_name), s && s->id ? s->id : "(null)");
+                                  session_name, s && s->id ? s->id : "NULL");
 #endif // 0
         }
 
         if (ret)
                 *ret = s;
 
-        return !!s;
+        return 1;
+
+not_found:
+        if (ret)
+                *ret = NULL;
+        return 0;
 }
 
 int manager_get_user_by_pid(Manager *m, pid_t pid, User **ret) {
 #if 0 /// elogind does not support systemd units, but its own session system
         _cleanup_free_ char *unit = NULL;
+        User *u;
 #else // 0
         Session *s;
 #endif // 0
-        User *u = NULL;
         int r;
 
         assert(m);
@@ -464,19 +476,32 @@ int manager_get_user_by_pid(Manager *m, pid_t pid, User **ret) {
 
 #if 0 /// elogind does not support systemd units, but its own session system
         r = cg_pid_get_slice(pid, &unit);
-        if (r >= 0)
-                u = hashmap_get(m->user_units, unit);
-#else // 0
-        // If a session was found, ignore it if it is already closing.
-        r = manager_get_session_by_pid (m, pid, &s);
-        if ( (r >= 0) && (SESSION_CLOSING != session_get_state(s)) )
-                u = s->user;
-#endif // 0
+        if (r < 0)
+                goto not_found;
+
+        u = hashmap_get(m->user_units, unit);
+        if (!u)
+                goto not_found;
 
         if (ret)
                 *ret = u;
 
-        return !!u;
+#else // 0
+        // If a session was found, ignore it if it is already closing.
+        r = manager_get_session_by_pid (m, pid, &s);
+        if (r <= 0 || SESSION_CLOSING == session_get_state(s))
+                goto not_found;
+
+        if (ret)
+                *ret =  s->user;
+#endif // 0
+        return 1;
+
+not_found:
+        if (ret)
+                *ret = NULL;
+
+        return 0;
 }
 
 int manager_get_idle_hint(Manager *m, dual_timestamp *t) {
