@@ -15,7 +15,6 @@
 //#include "device-nodes.h"
 #include "dirent-util.h"
 #include "efivars.h"
-#include "efi-loader.h"
 #include "env-file.h"
 #include "env-util.h"
 #include "fd-util.h"
@@ -36,7 +35,6 @@ static void boot_entry_free(BootEntry *entry) {
         assert(entry);
 
         free(entry->id);
-        free(entry->id_old);
         free(entry->path);
         free(entry->root);
         free(entry->title);
@@ -74,13 +72,12 @@ static int boot_entry_load(
                 return log_error_errno(SYNTHETIC_ERRNO(EINVAL), "Invalid loader entry file suffix: %s", path);
 
         b = basename(path);
-        tmp.id = strdup(b);
-        tmp.id_old = strndup(b, c - b);
-        if (!tmp.id || !tmp.id_old)
+        tmp.id = strndup(b, c - b);
+        if (!tmp.id)
                 return log_oom();
 
         if (!efi_loader_entry_name_valid(tmp.id))
-                return log_error_errno(SYNTHETIC_ERRNO(EINVAL), "Invalid loader entry: %s", tmp.id);
+                return log_error_errno(SYNTHETIC_ERRNO(EINVAL), "Invalid loader entry filename: %s", path);
 
         tmp.path = strdup(path);
         if (!tmp.path)
@@ -263,7 +260,7 @@ static int boot_entries_find(
         assert(entries);
         assert(n_entries);
 
-        r = conf_files_list(&files, ".conf", NULL, 0, dir);
+        r = conf_files_list(&files, ".conf", NULL, 0, dir, NULL);
         if (r < 0)
                 return log_error_errno(r, "Failed to list files in \"%s\": %m", dir);
 
@@ -294,7 +291,6 @@ static int boot_entry_load_unified(
         };
         _cleanup_fclose_ FILE *f = NULL;
         const char *k;
-        char *b;
         int r;
 
         assert(root);
@@ -320,10 +316,8 @@ static int boot_entry_load_unified(
         if (!os_pretty_name || !os_id || !(version_id || build_id))
                 return log_error_errno(SYNTHETIC_ERRNO(EBADMSG), "Missing fields in os-release data from unified kernel image %s, refusing.", path);
 
-        b = basename(path);
-        tmp.id = strdup(b);
-        tmp.id_old = strjoin(os_id, "-", version_id ?: build_id);
-        if (!tmp.id || !tmp.id_old)
+        tmp.id = strjoin(os_id, "-", version_id ?: build_id);
+        if (!tmp.id)
                 return log_oom();
 
         if (!efi_loader_entry_name_valid(tmp.id))
