@@ -11,8 +11,6 @@
 typedef enum TableDataType {
         TABLE_EMPTY,
         TABLE_STRING,
-        TABLE_STRV,
-        TABLE_PATH,
         TABLE_BOOLEAN,
         TABLE_TIMESTAMP,
         TABLE_TIMESTAMP_UTC,
@@ -37,8 +35,6 @@ typedef enum TableDataType {
         TABLE_IN_ADDR,  /* Takes a union in_addr_union (or a struct in_addr) */
         TABLE_IN6_ADDR, /* Takes a union in_addr_union (or a struct in6_addr) */
 #endif // 0
-        TABLE_ID128,
-        TABLE_UUID,
         _TABLE_DATA_TYPE_MAX,
 
         /* The following are not really data types, but commands for table_add_cell_many() to make changes to
@@ -59,12 +55,6 @@ typedef enum TableDataType {
 #define TABLE_PID TABLE_INT32
 assert_cc(sizeof(pid_t) == sizeof(int32_t));
 
-/* UIDs/GIDs are just 32bit unsigned integers on Linux */
-#define TABLE_UID TABLE_UINT32
-#define TABLE_GID TABLE_UINT32
-assert_cc(sizeof(uid_t) == sizeof(uint32_t));
-assert_cc(sizeof(gid_t) == sizeof(uint32_t));
-
 typedef struct Table Table;
 typedef struct TableCell TableCell;
 
@@ -107,7 +97,6 @@ int table_add_many_internal(Table *t, TableDataType first_type, ...);
 
 void table_set_header(Table *table, bool b);
 void table_set_width(Table *t, size_t width);
-void table_set_cell_height_max(Table *t, size_t height);
 int table_set_empty_string(Table *t, const char *empty);
 int table_set_display(Table *t, size_t first_column, ...);
 int table_set_sort(Table *t, size_t first_column, ...);
@@ -136,6 +125,3 @@ const void *table_get_at(Table *t, size_t row, size_t column);
 
 int table_to_json(Table *t, JsonVariant **ret);
 int table_print_json(Table *t, FILE *f, JsonFormatFlags json_flags);
-
-#define table_log_add_error(r) \
-        log_error_errno(r, "Failed to add cell(s) to table: %m")
